@@ -26,7 +26,8 @@ class IChannelSMTP(IChannel):
     fromAddress = ASCIILine(title=_(u'"From" address'))
     
     bccAddress = ASCIILine(title = _(u'"BCC" addreses (use commas as splitter)'),
-                           required = False)
+                           required = False,
+                           default = '')
 
     delivery = Choice(
         title=_(u"Mail Delivery Name"),
